pub struct DucPath {
pub line_indices: Vec<i32>,
pub background: Option<ElementBackground>,
pub stroke: Option<ElementStroke>,
}Fields
line_indices: Vec<i32>background: Option<ElementBackground>Override the background and stroke from the base if different than null
stroke: Option<ElementStroke>Override the background and stroke from the base if different than null