Module types

Module types 

Structs

BoundElement
Checkpoint
CustomHatchPattern
Delta
DictionaryEntry
A generic key-value pair for string dictionaries.
DocumentGridConfig
DucArrowElement
DucBlock
DucBlockCollection
DucBlockCollectionEntry
DucBlockDuplicationArray
DucBlockInstance
DucBlockMetadata
DucDocElement
DucDocStyle
DucElementBase
The foundational table for all scene elements, containing common properties.
DucElementStylesBase
Base style properties shared by many elements.
DucEllipseElement
DucEmbeddableElement
DucExternalFileData
DucExternalFileEntry
DucFrameElement
DucFreeDrawElement
DucFreeDrawEnds
DucGlobalState
DucGroup
DucHatchStyle
DucHead
DucImageElement
DucImageFilter
DucLayer
DucLayerOverrides
DucLine
DucLineReference
DucLinearElement
DucLinearElementBase
The base for linear elements like lines and arrows.
DucLocalState
DucModelElement
DucPath
DucPdfElement
DucPlotElement
DucPlotStyle
DucPoint
DucPointBinding
DucPolygonElement
DucRectangleElement
DucRegion
DucStackBase
DucStackElementBase
DucStackLikeStyles
DucTableElement
DucTableStyle
DucTextElement
DucTextStyle
ElementBackground
ElementContentBase
ElementStroke
ElementWrapper
A wrapper to hold an element from the union.
ExportedDataState
Root data structure for the stored data state
ExternalFileMetadata
Lightweight metadata for an external file (no data blob).
GeometricPoint
A high-precision 2D point in the World Coordinate System.
HatchPatternLine
ImageCrop
LineSpacing
Margins
Represents margins for layouts and cells.
PlotLayout
PointBindingPoint
SchemaMigration
StringValueEntry
A generic key-value pair for more complex structures like DucBlock attribute values.
StrokeSides
StrokeStyle
TilingProperties
VersionBase
VersionChain
VersionGraph
VersionGraphMetadata
Viewer3DCamera
Viewer3DClipPlane
Viewer3DClipping
Viewer3DDisplay
Viewer3DExplode
Viewer3DGridPlanes
Viewer3DMaterial
Viewer3DState
Viewer3DZebra

Enums

BEZIER_MIRRORING
BLENDING
BOOLEAN_OPERATION
Defines the types of boolean operations that can be performed.
DucElementEnum
DucElementVariant
ELEMENT_CONTENT_PREFERENCE
ElementType
HATCH_STYLE
IMAGE_STATUS
LINE_HEAD
LINE_SPACING_TYPE
Determines how line spacing is interpreted.
PRUNING_LEVEL
STROKE_CAP
Shape used at the end of stroked segments.
STROKE_JOIN
Join style for adjacent stroked segments.
STROKE_PLACEMENT
Placement of stroke relative to the element boundary.
STROKE_PREFERENCE
Preferred stroke rendering style.
STROKE_SIDE_PREFERENCE
Applies stroke to specific sides of an element.
TEXT_ALIGN
Aligns text horizontally within its bounding box.
VERTICAL_ALIGN
Aligns text vertically within its bounding box.
Viewer3DGrid