Structs
- Bound
Element - Checkpoint
- Custom
Hatch Pattern - Delta
- Dictionary
Entry - A generic key-value pair for string dictionaries.
- Document
Grid Config - DucArrow
Element - DucBlock
- DucBlock
Collection - DucBlock
Collection Entry - DucBlock
Duplication Array - DucBlock
Instance - DucBlock
Metadata - DucDoc
Element - DucDoc
Style - DucElement
Base - The foundational table for all scene elements, containing common properties.
- DucElement
Styles Base - Base style properties shared by many elements.
- DucEllipse
Element - DucEmbeddable
Element - DucExternal
File Data - DucExternal
File Entry - DucFrame
Element - DucFree
Draw Element - DucFree
Draw Ends - DucGlobal
State - DucGroup
- DucHatch
Style - DucHead
- DucImage
Element - DucImage
Filter - DucLayer
- DucLayer
Overrides - DucLine
- DucLine
Reference - DucLinear
Element - DucLinear
Element Base - The base for linear elements like lines and arrows.
- DucLocal
State - DucModel
Element - DucPath
- DucPdf
Element - DucPlot
Element - DucPlot
Style - DucPoint
- DucPoint
Binding - DucPolygon
Element - DucRectangle
Element - DucRegion
- DucStack
Base - DucStack
Element Base - DucStack
Like Styles - DucTable
Element - DucTable
Style - DucText
Element - DucText
Style - Element
Background - Element
Content Base - Element
Stroke - Element
Wrapper - A wrapper to hold an element from the union.
- Exported
Data State - Root data structure for the stored data state
- External
File Metadata - Lightweight metadata for an external file (no data blob).
- Geometric
Point - A high-precision 2D point in the World Coordinate System.
- Hatch
Pattern Line - Image
Crop - Line
Spacing - Margins
- Represents margins for layouts and cells.
- Plot
Layout - Point
Binding Point - Schema
Migration - String
Value Entry - A generic key-value pair for more complex structures like DucBlock attribute values.
- Stroke
Sides - Stroke
Style - Tiling
Properties - Version
Base - Version
Chain - Version
Graph - Version
Graph Metadata - Viewer3D
Camera - Viewer3D
Clip Plane - Viewer3D
Clipping - Viewer3D
Display - Viewer3D
Explode - Viewer3D
Grid Planes - Viewer3D
Material - Viewer3D
State - Viewer3D
Zebra
Enums
- BEZIER_
MIRRORING - BLENDING
- BOOLEAN_
OPERATION - Defines the types of boolean operations that can be performed.
- DucElement
Enum - DucElement
Variant - ELEMENT_
CONTENT_ PREFERENCE - Element
Type - HATCH_
STYLE - IMAGE_
STATUS - LINE_
HEAD - LINE_
SPACING_ TYPE - Determines how line spacing is interpreted.
- PRUNING_
LEVEL - STROKE_
CAP - Shape used at the end of stroked segments.
- STROKE_
JOIN - Join style for adjacent stroked segments.
- STROKE_
PLACEMENT - Placement of stroke relative to the element boundary.
- STROKE_
PREFERENCE - Preferred stroke rendering style.
- STROKE_
SIDE_ PREFERENCE - Applies stroke to specific sides of an element.
- TEXT_
ALIGN - Aligns text horizontally within its bounding box.
- VERTICAL_
ALIGN - Aligns text vertically within its bounding box.
- Viewer3D
Grid